#!/bin/sh

# This helper script will handle deploying an amazonmq broker
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

if [ -z "${brokerName}" ]; then
  echo "Must set env brokerName"
  exit 1
fi

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "broker_password = \"${primaryPassword}\"" > ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get endpoint1 endpoint1Value
terraform_get endpoint2 endpoint2Value

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  Endpoint1: ${endpoint1Value}
  Endpoint2: ${endpoint2Value}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

create_hostname_configmap ${namingPrefix}-endpoint ${appsNamespace} "--from-literal=endpoint1=${endpoint1Value}" "--from-literal=endpoint2=${endpoint2Value}"
create_hostname_configmap ${namingPrefix}-endpoint ${infraNamespace} "--from-literal=endpoint1=${endpoint1Value}" "--from-literal=endpoint2=${endpoint2Value}"

cprint "$0 done "
